# {{ name }} Contributing Guide

{{#issue}}- [Issue Reporting Guidelines](#issue-reporting-guidelines){{/issue}}
- [Pull Request Guidelines](#pull-request-guidelines)
- [Development Setup](#development-setup)

{{#issue}}
## Issue Reporting Guidelines

- The issue list of this repo is **exclusively** for bug reports and feature requests. Non-conforming issues will be closed immediately.

  - For simple beginner questions, you can get quick answers from [The Gitter chat room](https://gitter.im/vuejs/vue).

  - For more complicated questions, you can use [the official forum](http://forum.vuejs.org/) or StackOverflow. Make sure to provide enough information when asking your questions - this makes it easier for others to help you!

- Try to search for your issue, it may have already been answered or even fixed in the development branch.

- Check if the issue is reproducible with the latest stable version of Vue. If you are using a pre-release, please indicate the specific version you are using.

- It is **required** that you clearly describe the steps necessary to reproduce the issue you are running into. Issues with no clear repro steps will not be triaged. If an issue labeled "need repro" receives no further input from the issue author for more than 5 days, it will be closed.

- It is recommended that you make a JSFiddle/JSBin/Codepen to demonstrate your issue. You could start with [this template](http://jsfiddle.net/5sH6A/) that already includes the latest version of Vue.

- For bugs that involves build setups, you can create a reproduction repository with steps in the README.

- If your issue is resolved but still open, don’t hesitate to close it. In case you found a solution by yourself, it could be helpful to explain how you fixed it.
{{/issue}}

## Pull Request Guidelines

- The `master` branch is basically just a snapshot of the latest stable release. All development should be done in dedicated branches. **Do not submit PRs against the `master` branch.**

- Checkout a topic branch from the relevant branch, e.g. `{{ branch }}`, and merge back against that branch.

- Work in the `src` folder and **DO NOT** checkin `dist` in the commits.

- It's OK to have multiple small commits as you work on the PR - we will let GitHub automatically squash it before merging.

- Make sure `npm test` passes. (see [development setup](#development-setup))

- If adding new feature:
  - Add accompanying test case.
  - Provide convincing reason to add this feature. Ideally you should open a suggestion issue first and have it greenlighted before working on it.

- If fixing a bug:
  - Provide detailed description of the bug in the PR. Live demo preferred.
  - Add appropriate test coverage if applicable.

### Work Step Example
- Fork the repository from [{{ githubAccount }}/{{ name }}](https://github.com/{{ githubAccount }}/{{ name }}) !
- Create your topic branch from `{{ branch }}`: `git branch my-new-topic origin/{{ branch }}`
- Add codes and pass tests !
- Commit your changes: `git commit -am 'Add some topic'`
- Push to the branch: `git push origin my-new-topic`
{{#unless_eq githubAccount ""}}
- Submit a pull request to `{{ branch }}` branch of `{{ githubAccount }}/{{ name }}` repository !
{{/unless_eq}}

## Development Setup

You will need [Node.js](http://nodejs.org){{#e2e}} and [Java Runtime Environment](http://www.oracle.com/technetwork/java/javase/downloads/index.html) (needed for running Selenium server during e2e tests){{/e2e}}.

After cloning the repo, run:

    $ npm install

### Commonly used NPM scripts

    # watch and serve with hot reload unit test at localhost:8080
    $ npm run dev

    # lint source codes
    $ npm run lint

    # run unit tests in browser (firefox/safari/chrome)
    $ npm run test:unit

    # build all dist files, including npm packages
    $ npm run build

    # run the full test suite, include linting{{#flow}} / type checking{{/flow}}
    $ npm test

There are some other scripts available in the `scripts` section of the `package.json` file.

The default test script will do the following: lint with ESLint{{#flow}} -> type check with Flow{{/flow}} -> unit tests with coverage{{#e2e}} -> e2e tests{{/e2e}}. **Please make sure to have this pass successfully before submitting a PR.** Although the same tests will be run against your PR on the CI server, it is better to have it working locally beforehand.

